@@ -1,8 +1,9 @@
 import time
 
+from typing import Tuple
 from .bc_reader import BCReader, BCInfo
 
-READERS = tuple[BCReader]
+READERS = Tuple[BCReader]
 
 
 class CardReader(object):
