@@ -1,7 +1,6 @@
 import random
 
 from typing import Dict
-from collections.abc import Callable
 from datetime import datetime
 from loguru import logger
 
@@ -12,7 +11,7 @@ TLVDICT = Dict[str, bytes]
 
 class PBOC(object):
 
-    def __init__(self, runner: Callable[[str], str]):
+    def __init__(self, runner):
         super(PBOC, self).__init__()
         self.exec = runner
 
